@@ -7,7 +7,7 @@
 //*****************************************************************************/ 
 // ľܸƤӽФ줿exit
 //*****************************************************************************/ 
-$replace_array = array( '\\' => '/', '\\.\\' => '\\', '/./' => '/' );
+$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
 if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) === strtr(__FILE__, '\\', '/') )  exit;
 
 //*****************************************************************************/
